{
  "name": "PersianNews",
  "version": "1.0.0",
  "task": "Classification",
  "splits": ["train", "test", "dev"],
  "description": "source: https://huggingface.co/HooshvareLab/bert-fa-base-uncased-clf-persiannews",
  "size" : {"train": 13179, "dev": 1469, "test":1623},
  "filenames": ["persian_news/train.csv", "persian_news/test.csv", "persian_news/dev.csv"]
}
